@@ -1,2 +1,2 @@
-from .pyB12MPS import *
+from .mps import *
 from .version import __version__
